==> haskell-stream-0.4.7.2-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-Hmd5wt67H0oCIYDdwfcZtO
key:                  Stream-0.4.7.2-Hmd5wt67H0oCIYDdwfcZtO
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  0319a897e72f815b8de993c66a84d39f
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.0.1/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Stream-0.4.7.2
hs-libraries:         HSStream-0.4.7.2-Hmd5wt67H0oCIYDdwfcZtO
depends:
    QuickCheck-2.14.2-Ah3Pa5Fl9gvF5c5fvpDPwz base-4.15.0.0
    lazysmallcheck-0.6-IFdnbuYmhkmEQtFy7QHeNo

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stream-0.4.7.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-Nh51gQY8wdE5eH9BqzEpW
key:                  Stream-0.4.7.2-Nh51gQY8wdE5eH9BqzEpW
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  93ee58029b9b8f7c0accc653dd5553f3
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.0.1/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Stream-0.4.7.2
hs-libraries:         HSStream-0.4.7.2-Nh51gQY8wdE5eH9BqzEpW
depends:
    QuickCheck-2.14.2-4fFmALdK9KzLSVxePLHYEq base-4.15.0.0
    lazysmallcheck-0.6-IFdnbuYmhkmEQtFy7QHeNo

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
